package com.fs.hisStore.service;

import java.util.List;
import com.fs.hisStore.domain.FsStoreShopScrm;

/**
 * 门店自提Service接口
 * 
 * @author fs
 * @date 2022-03-15
 */
public interface IFsStoreShopScrmService 
{
    /**
     * 查询门店自提
     * 
     * @param id 门店自提ID
     * @return 门店自提
     */
    public FsStoreShopScrm selectFsStoreShopById(Long id);

    /**
     * 查询门店自提列表
     * 
     * @param fsStoreShop 门店自提
     * @return 门店自提集合
     */
    public List<FsStoreShopScrm> selectFsStoreShopList(FsStoreShopScrm fsStoreShop);

    /**
     * 新增门店自提
     * 
     * @param fsStoreShop 门店自提
     * @return 结果
     */
    public int insertFsStoreShop(FsStoreShopScrm fsStoreShop);

    /**
     * 修改门店自提
     * 
     * @param fsStoreShop 门店自提
     * @return 结果
     */
    public int updateFsStoreShop(FsStoreShopScrm fsStoreShop);

    /**
     * 批量删除门店自提
     * 
     * @param ids 需要删除的门店自提ID
     * @return 结果
     */
    public int deleteFsStoreShopByIds(Long[] ids);

    /**
     * 删除门店自提信息
     * 
     * @param id 门店自提ID
     * @return 结果
     */
    public int deleteFsStoreShopById(Long id);
}
